@@ -9,12 +9,12 @@
 -- {artefact} for artefacts.
 -- {ego} for identified branded items.
 -- { <skill> } - the relevant weapon skill for weapons.
+-- { <num>-handed } - the handedness of the weapon for weapons.
 -- { <class> } - item class: gold, weapon, missile, wand, carrion, food,
 --               scroll, jewellery, potion, book, magical staff, orb, misc,
 --               <armourtype> armour
 -- { <ego> } - short item ego description: rC+, rPois, SInv, freeze etc.
 -- {god gift} for god gifts
--- {fruit} for fruit
 --
 -- Item annotations are always prefixed to the item name. For instance:
 -- {artefact} the Staff of Wucad Mu
@@ -50,13 +50,19 @@ function ch_stash_search_annotate_item(it)
     annot = annot .. "{god gift} "
   end
 
-  if food.isfruit(it) then
-    annot = annot .. "{fruit} "
-  end
-
   local skill = it.weap_skill
   if skill then
     annot = annot .. "{" .. skill .. "} "
+    local hands = it.hands
+    local hands_adj
+    if hands == 2 then
+      hands_adj = "two-handed"
+    else
+      hands_adj = "one-handed"
+    end
+    if skill ~= "Throwing" then
+      annot = annot .. "{" .. hands_adj .. "} "
+    end
   end
 
   if it.ego_type_terse ~= "" and it.ego_type_terse ~= "unknown" then
@@ -71,10 +77,8 @@ function ch_stash_search_annotate_item(it)
          or it.ego_type_terse == "EV" or it.ego_type_terse == "AC" then
         if it.plus == nil then
           annot = annot .. "+"
-        elseif it.plus < 0 then
-          annot = annot .. "-" .. it.plus
         else
-          annot = annot .. "+" .. it.plus
+          annot = annot .. string.format("%+d", it.plus)
         end
       end
       annot = annot .. "} "
@@ -92,7 +96,6 @@ function ch_stash_search_annotate_item(it)
       ["fire"] = "rF+",
       ["poison"] = "rPois",
       ["power"] = "MP+",
-      ["summoning"] = "Ward",
       ["wizardry"] = "Wiz"
     }
     if props[it.subtype()] then
@@ -104,7 +107,7 @@ function ch_stash_search_annotate_item(it)
     local props = {
       ["troll"] = "Regen+",
       ["steam"] = "rSteam",
-      ["mottled"] = "rNapalm",
+      ["acid"] = "rCorr",
       ["quicksilver"] = "MR+",
       ["swamp"] = "rPois",
       ["fire"] = "rF++ rC-",
@@ -137,6 +140,10 @@ function ch_stash_search_annotate_item(it)
   end
   annot = annot .. it.class(true) .. "}"
 
+  if it.class(true) == "armour" then
+      annot = annot .. " {" .. it.subtype() .. " armor}"
+  end
+
   local resistances = {
     ["MR+"] = "magic",
     ["rC+"] = "cold",
